@@ -337,6 +337,7 @@ class UploadPhotoMixin:
         links: List[StoryLink] = [],
         hashtags: List[StoryHashtag] = [],
         stickers: List[StorySticker] = [],
+        extra_data: Dict[str, str] = {},
     ) -> Dict:
         """
         Post configure photo
@@ -361,6 +362,8 @@ class UploadPhotoMixin:
             List of hashtags to be tagged on this upload, default is empty list.
         stickers: List[StorySticker], optional
             List of stickers to be tagged on this upload, default is empty list.
+        extra_data: List[str, str], optional
+            Dict of extra data, if you need to add your params, like {"share_to_facebook": 1}.
 
         Returns
         -------
@@ -396,6 +399,7 @@ class UploadPhotoMixin:
             },
             "extra": {"source_width": width, "source_height": height},
         }
+        data.update(extra_data)
         if links:
             links = [link.dict() for link in links]
             data["story_cta"] = dumps([{"links": links}])
